package rescuecore.mas08.com;

/**
 * Base class for objects being sent through the com interface.
 * 
 */
public abstract class CommObject {
	/**
	 * The type describing, how to interpret this {@link CommObject}.
	 * See {@link CommInterface} for valid values.
	 */
    protected byte type;
    protected byte channel;
    
	public CommObject(byte type) {
		this.type = type;
		this.channel = 0;
	}

	public byte getType() {
		return type;
	}

	public byte getChannel() {
		return channel;
	}

	public void setChannel(byte channel) {
		this.channel = channel;
	}
	
	/**
	 * Encode this CommObject into a byte [].
	 * 
	 * @param msg - the byte[] to encode into
	 * @param start - the start index, from that the byte[] will be free to write to
	 * @return the next start index, that is free to write to or -1 on failure (missing space)
	 */
	public abstract int encode(byte [] msg, int start);

	/**
	 * Decode this CommObject from the byte[].
	 * 
	 * @param msg - the byte[] with information about this object.
	 * @param start - the start index for decoding.
	 * @return the next start index for decoding or -1 on failure.
	 */
	public abstract int decode(byte [] msg, int start);

}